#!/bin/sh
# ----------------------------------------------------------------------------
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
# ----------------------------------------------------------------------------

#   Copyright (c) 2001-2002 The Apache Software Foundation.  All rights
#   reserved.

# ----------------------------------------------------------------------------
# WSO2 Unified Product Start Up Batch script
#
# Required ENV vars:
# ------------------
#   JAVA_HOME - location of a JDK home dir
#
# Optional ENV vars
# -----------------
#   UNIFIED_HOME - location of maven2's installed home dir
#   JAVA_OPTS - parameters passed to the Java VM when running Maven
#     e.g. to debug Maven itself, use
#       set JAVA_OPTS=-Xdebug -Xnoagent -Djava.compiler=NONE -Xrunjdwp:transport=dt_socket,server=y,suspend=y,address=8000
# ----------------------------------------------------------------------------


QUOTED_ARGS=""
while [ "$1" != "" ] ; do

  QUOTED_ARGS="$QUOTED_ARGS \"$1\""
  shift

done

# OS specific support.  $var _must_ be set to either true or false.
cygwin=false;
darwin=false;
mingw=false
case "`uname`" in
  CYGWIN*) cygwin=true ;;
  MINGW*) mingw=true;;
  Darwin*) darwin=true
           if [ -z "$JAVA_VERSION" ] ; then
             JAVA_VERSION="CurrentJDK"
           else
             echo "Using Java version: $JAVA_VERSION"
           fi
           if [ -z "$JAVA_HOME" ] ; then
             JAVA_HOME=/System/Library/Frameworks/JavaVM.framework/Versions/${JAVA_VERSION}/Home
           fi
           ;;
esac

if [ -z "$JAVA_HOME" ] ; then
  if [ -r /etc/gentoo-release ] ; then
    JAVA_HOME=`java-config --jre-home`
  fi
fi

if [ -z "$UNIFIED_HOME" ] ; then
  ## resolve links - $0 may be a link to maven's home
  PRG="$0"

  # need this for relative symlinks
  while [ -h "$PRG" ] ; do
    ls=`ls -ld "$PRG"`
    link=`expr "$ls" : '.*-> \(.*\)$'`
    if expr "$link" : '/.*' > /dev/null; then
      PRG="$link"
    else
      PRG="`dirname "$PRG"`/$link"
    fi
  done

  saveddir=`pwd`

  UNIFIED_HOME=`dirname "$PRG"`/..

  # make it fully qualified
  UNIFIED_HOME=`cd "$UNIFIED_HOME" && pwd`

  cd "$saveddir"
  # echo Using unified product home at $UNIFIED_HOME
fi

# For Cygwin, ensure paths are in UNIX format before anything is touched
if $cygwin ; then
  [ -n "$UNIFIED_HOME" ] &&
    UNIFIED_HOME=`cygpath --unix "$UNIFIED_HOME"`
  [ -n "$JAVA_HOME" ] &&
    JAVA_HOME=`cygpath --unix "$JAVA_HOME"`
  [ -n "$CLASSPATH" ] &&
    CLASSPATH=`cygpath --path --unix "$CLASSPATH"`
fi

# For Migwn, ensure paths are in UNIX format before anything is touched
if $mingw ; then
  [ -n "$UNIFIED_HOME" ] &&
    UNIFIED_HOME="`(cd "$UNIFIED_HOME"; pwd)`"
  [ -n "$JAVA_HOME" ] &&
    JAVA_HOME="`(cd "$JAVA_HOME"; pwd)`"
  # TODO classpath?
fi

if [ -z "$JAVACMD" ] ; then
  if [ -n "$JAVA_HOME"  ] ; then
    if [ -x "$JAVA_HOME/jre/sh/java" ] ; then
      # IBM's JDK on AIX uses strange locations for the executables
      JAVACMD="$JAVA_HOME/jre/sh/java"
    else
      JAVACMD="$JAVA_HOME/bin/java"
    fi
  else
    JAVACMD=java
  fi
fi

if [ ! -x "$JAVACMD" ] ; then
  echo "Error: JAVA_HOME is not defined correctly."
  echo "  We cannot execute $JAVACMD"
  exit 1
fi

if [ -z "$JAVA_HOME" ] ; then
  echo "Warning: JAVA_HOME environment variable is not set."
fi
# update classpath
PLATFORM_CLASSPATH=""
for f in "$UNIFIED_HOME"/lib/*.jar
do
  PLATFORM_CLASSPATH="$PLATFORM_CLASSPATH":$f
done

for f in "$UNIFIED_HOME"/lib/tomcat/*.jar
do
  PLATFORM_CLASSPATH="$PLATFORM_CLASSPATH":$f
done

for f in "$UNIFIED_HOME"/lib/axis2/*.jar
do
  PLATFORM_CLASSPATH="$PLATFORM_CLASSPATH":$f
done

PLATFORM_CLASSPATH="$UNIFIED_HOME/conf":"$PLATFORM_CLASSPATH"

CLASSWORLDS_LAUNCHER=org.wso2.carbon.Main

# For Cygwin, switch paths to Windows format before running java
if $cygwin; then
  [ -n "$UNIFIED_HOME" ] &&
    UNIFIED_HOME=`cygpath --path --windows "$UNIFIED_HOME"`
  [ -n "$JAVA_HOME" ] &&
    JAVA_HOME=`cygpath --path --windows "$JAVA_HOME"`
  [ -n "$HOME" ] &&
    HOME=`cygpath --path --windows "$HOME"`
fi

exec "$JAVACMD" \
  $JAVA_OPTS \
  -classpath "$PLATFORM_CLASSPATH" \
  -Djava.endorsed.dirs="$UNIFIED_HOME/lib/endorsed":"$JAVA_HOME/jre/lib/endorsed":"$JAVA_HOME/lib/endorsed" \
  -Djava.io.tmpdir="$UNIFIED_HOME/tmp" \
  "-Dcarbon.home=${UNIFIED_HOME}"  \
  ${CLASSWORLDS_LAUNCHER} $QUOTED_ARGS
